==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/uk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "Your browser is not supported!" : "Ваш браузер не підтримується!",
    "No media files found" : "Відсутні мультимедійні файли.",
    "Configuration error" : "Помилка конфігурації",
    "New" : "Створити",
    "Error loading slideshow template" : "Помилка завантаження шаблона слайд-шоу",
    "Next" : "Наступний",
    "Play" : "Грати",
    "Pause" : "Пауза",
    "Previous" : "Попередній",
    "Close" : "Закрити",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Upload" : "Вивантажити",
    "Error" : "Помилка",
    "Error while sharing" : "Помилка під час публікації",
    "Error while unsharing" : "Помилка під час відміни публікації",
    "Error while changing permissions" : "Помилка при зміні повноважень",
    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
    "Shared with you by {owner}" : "{owner} опублікував для Вас",
    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
    "Share" : "Поділитися",
    "Share link" : "Поділитись посиланням",
    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
    "Link" : "Посилання",
    "Password protect" : "Захистити паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
    "Allow editing" : "Дозволити редагування",
    "Email link to person" : "Надіслати посилання електронною поштою",
    "Send" : "Надіслати",
    "Set expiration date" : "Встановити термін дії",
    "Expiration" : "Закінчення",
    "Expiration date" : "Термін дії",
    "An error occured. Please try again" : "Виникла помилка. Будь ласка, спробуйте ще раз",
    "Adding user..." : "Додавання користувача...",
    "group" : "група",
    "remote" : "Віддалений",
    "Resharing is not allowed" : "Пере-публікація не дозволяється",
    "Unshare" : "Закрити спільний доступ",
    "notify by email" : "повідомити по Email",
    "can share" : "може ділитися з іншими",
    "can edit" : "може редагувати",
    "access control" : "контроль доступу",
    "create" : "створити",
    "change" : "змінити",
    "delete" : "видалити",
    "Password protected" : "Захищено паролем",
    "Error unsetting expiration date" : "Помилка при відміні терміну дії",
    "Error setting expiration date" : "Помилка при встановленні терміну дії",
    "Sending ..." : "Надсилання...",
    "Email sent" : "Лист надіслано",
    "Warning" : "Попередження",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Sort by date" : "Сортувати за датою",
    "Sort by name" : "Впорядкувати за ім’ям",
    "Cancel upload" : "Скасувати вивантаження",
    "Album information" : "Інформація про альбом",
    "File list" : "Список файлів",
    "Sorry, this file could not be found." : "Вибачте, цей файл не може бути знайдено.",
    "Reasons might be:" : "Можливі причини:",
    "the file was removed" : "файл був видалений",
    "the file is corrupt" : "файл пошкоджений",
    "Here is the error message returned by the server: " : "Ось повідомлення про помилку, що повертається сервером:",
    "the filesystem is not readable" : "неможливо прочитати файлову систему",
    "the item was removed" : "цей пункт був вилучений",
    "the link has expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "Picture view" : "Перегляд Зображення"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/uk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Галерея",
    "Your browser is not supported!" : "Ваш браузер не підтримується!",
    "No media files found" : "Відсутні мультимедійні файли.",
    "Configuration error" : "Помилка конфігурації",
    "New" : "Створити",
    "Error loading slideshow template" : "Помилка завантаження шаблона слайд-шоу",
    "Next" : "Наступний",
    "Play" : "Грати",
    "Pause" : "Пауза",
    "Previous" : "Попередній",
    "Close" : "Закрити",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Share" : "Поділитися",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Upload" : "Вивантажити",
    "Error" : "Помилка",
    "Error while sharing" : "Помилка під час публікації",
    "Error while unsharing" : "Помилка під час відміни публікації",
    "Error while changing permissions" : "Помилка при зміні повноважень",
    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
    "Shared with you by {owner}" : "{owner} опублікував для Вас",
    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
    "Share link" : "Поділитись посиланням",
    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
    "Link" : "Посилання",
    "Password protect" : "Захистити паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
    "Allow editing" : "Дозволити редагування",
    "Email link to person" : "Надіслати посилання електронною поштою",
    "Send" : "Надіслати",
    "Set expiration date" : "Встановити термін дії",
    "Expiration" : "Закінчення",
    "Expiration date" : "Термін дії",
    "An error occured. Please try again" : "Виникла помилка. Будь ласка, спробуйте ще раз",
    "Adding user..." : "Додавання користувача...",
    "group" : "група",
    "remote" : "Віддалений",
    "Resharing is not allowed" : "Пере-публікація не дозволяється",
    "Unshare" : "Закрити спільний доступ",
    "notify by email" : "повідомити по Email",
    "can share" : "може ділитися з іншими",
    "can edit" : "може редагувати",
    "access control" : "контроль доступу",
    "create" : "створити",
    "change" : "змінити",
    "delete" : "видалити",
    "Password protected" : "Захищено паролем",
    "Error unsetting expiration date" : "Помилка при відміні терміну дії",
    "Error setting expiration date" : "Помилка при встановленні терміну дії",
    "Email sent" : "Лист надіслано",
    "Warning" : "Попередження",
    "This share is password-protected" : "Цей ресурс обміну захищений паролем",
    "The password is wrong. Try again." : "Невірний пароль. Спробуйте ще раз.",
    "Sort by name" : "Впорядкувати за ім’ям",
    "Sort by date" : "Сортувати за датою",
    "Cancel upload" : "Скасувати вивантаження",
    "Album information" : "Інформація про альбом",
    "File list" : "Список файлів",
    "Sorry, this file could not be found." : "Вибачте, цей файл не може бути знайдено.",
    "Reasons might be:" : "Можливі причини:",
    "the file was removed" : "файл був видалений",
    "the file is corrupt" : "файл пошкоджений",
    "Here is the error message returned by the server: " : "Ось повідомлення про помилку, що повертається сервером:",
    "the filesystem is not readable" : "неможливо прочитати файлову систему",
    "the item was removed" : "цей пункт був вилучений",
    "the link has expired" : "посилання застаріло",
    "sharing is disabled" : "обмін заборонений",
    "Picture view" : "Перегляд Зображення",
    "Sending ..." : "Надсилання..."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
